==> agschat-0.0.11.tar.gz: example/lib/view/contact_list_view.dart <==
import 'package:agschat_example/constants.dart';
import 'package:agschat_example/core/services/stream_socket.dart';
import 'package:agschat_example/core/viewmodel/contact_list_model.dart';
import 'package:agschat_example/helper/colors.dart';
import 'package:agschat_example/helper/custom_styles.dart';
import 'package:agschat_example/view/create_group_view.dart';
import 'package:agschat_example/view/widgets/comman.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';

class ContactListView extends StatefulWidget {
  ContactListView({
    Key? key,
    this.forMakeGroup = false,
    this.forAddMember = false,
  }) : super(key: key);
  bool forMakeGroup = false;
  bool forAddMember = false;
  @override
  _ContactListViewState createState() => _ContactListViewState();
}

class _ContactListViewState extends State<ContactListView> {
  RxList<UsersList> usersList = <UsersList>[].obs;
  String searchText = '';
  @override
  void initState() {
    super.initState();

    getUsers();
  }

  TextEditingController searchController = TextEditingController();
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        backgroundColor: themeColor,
        elevation: 0.8,
        title: Text(
          widget.forAddMember
              ? "Add Member"
              : widget.forMakeGroup
                  ? "Create Group"
                  : "Contact list",
          style:
              CustomTextStyles.medium(fontSize: 16.0, fontColor: Colors.black),
        ),
        iconTheme: const IconThemeData(color: Colors.black),
      ),
      bottomNavigationBar: widget.forMakeGroup
          ? SafeArea(
              child: GestureDetector(
                onTap: () {
                  var selectedUserObj = [];
                  var selectedUserIds = [];
                  selectedUserObj = [];
                  selectedUserIds = [];
                  usersList.forEach((element) {
                    if (element.isSelected.value) {
                      selectedUserObj.add({
                        "groups": element.groups,
                        "mobile_email": element.mobileEmail,
                        "name": element.name,
                        "userId": element.userId,
                        "profilePicture": element.profilePicture
                      });
                      selectedUserIds.add(element.userId);
                    }
                  });

                  if (selectedUserIds.isEmpty) {
                    Common.getSnackToast(
                      title: 'Error',
                      message: "Please select user",
                    );
                  } else {
                    if (widget.forAddMember) {
                      var selectedUser = [];
                      var selectedMembers = [];
                      if (Get.arguments != null) {
                        var participents = Get.arguments[0];
                        participents.forEach((val) {
                          selectedUser.add(val);
                          selectedMembers.add(val['userId']);
                        });
                      }
                      usersList.forEach((element) {
                        if (element.isSelected.value) {
                          selectedUser.add(element);
                          selectedMembers.add(element.userId);
                        }
                      });

                      var parameters = {
                        "secretKey": secKey,
                        "groupId": Get.arguments[1],
                        "users": selectedUser,
                        "members": selectedMembers,
                        "viewBy": selectedMembers
                      };
                      addMember(parameters);
                    } else {
                      Get.to(() => const CreateGroup(),
                          arguments: [selectedUserObj, selectedUserIds]);
                    }
                  }
                },
                child: Container(
                  height: 50,
                  margin: const EdgeInsets.only(top: 16, left: 20, right: 20),
                  decoration: BoxDecoration(
                    borderRadius: BorderRadius.circular(8.0),
                    color: Colors.blue,
                  ),
                  child: Center(
                    child: Text(
                      widget.forAddMember ? "Add" : "Next",
                      style: CustomTextStyles.semiBold(
                          fontSize: 18.0, fontColor: Colors.white),
                    ),
                  ),
                ),
              ),
            )
          : const SizedBox(),
      body: Column(
        children: [
          Padding(
            padding:
                const EdgeInsets.only(left: 20, right: 20, top: 8, bottom: 8),
            child: TextField(
              controller: searchController,
              onChanged: (val) {
                setState(() {
                  searchText = val;
                });
              },
              decoration: InputDecoration(
                hintText: "Search chat",
                hintStyle: CustomTextStyles.medium(
                    fontSize: 14.0, fontColor: Colors.black38),
                filled: true,
                fillColor: const Color(0xffEEEEEF),
                border: searchCommonBorderStyle,
                enabledBorder: searchCommonBorderStyle,
                disabledBorder: searchCommonBorderStyle,
                focusedBorder: searchCommonBorderStyle,
                focusedErrorBorder: searchCommonBorderStyle,
                errorBorder: searchCommonBorderStyle,
                contentPadding: const EdgeInsets.only(left: 6, right: 6),
                prefixIcon: const Padding(
                    padding: EdgeInsetsDirectional.only(start: 6.0),
                    child: Icon(Icons.search)),
              ),
            ),
          ),
          Expanded(
              child: StreamBuilder(
                  stream: getUsersSocket.getResponse,
                  builder:
                      (BuildContext context, AsyncSnapshot<dynamic> snapshot) {
                    if (snapshot.connectionState == ConnectionState.waiting) {
                      return const Center(child: CircularProgressIndicator());
                    }
                    usersList.clear();

                    snapshot.data['list'].forEach((val) {
                      usersList.add(UsersList(
                        userId: val['userId'],
                        profilePicture: val['profilePicture'],
                        groups: val['groups'],
                        mobileEmail: val['mobile_email'],
                        name: val['name'],
                        serverUserId: val['serverUserId'],
                      ));
                    });
                    if (widget.forAddMember) {
                      if (Get.arguments != null) {
                        if (usersList.isNotEmpty) {
                          var participentList = Get.arguments[0];
                          participentList.forEach((val) {
                            usersList.removeWhere(
                                (element) => element.userId == val['userId']);
                            usersList.refresh();
                          });
                        }
                      }
                    }
                    if (searchText.isNotEmpty) {
                      usersList.value = usersList.value.where((element) {
                        return element.name
                            .toString()
                            .toLowerCase()
                            .contains(searchText.toLowerCase());
                      }).toList();
                    }
                    return usersList.isEmpty
                        ? const Center(
                            child: Text("Data not found"),
                          )
                        : Obx(
                            () => ListView.separated(
                              padding: const EdgeInsets.only(
                                  left: 20, right: 20, top: 8),
                              itemBuilder: (context, index) {
                                return contactItem(usersList[index]);
                              },
                              separatorBuilder: (_, index) {
                                return const SizedBox(
                                  height: 8,
                                );
                              },
                              itemCount: usersList.length,
                            ),
                          );
                  }))
        ],
      ),
    );
  }

  var searchCommonBorderStyle = const OutlineInputBorder(
    borderSide: BorderSide(
      color: Color(0xffE6E6E6),
    ),
  );

  // void getContactList() {
  //   var body = {
  //     "secretKey":
  //         "U2FsdGVkX18AsTXTniJJwZ9KaiRWQki0Gike3TN%2BQyXws0hyLIdcRN4abTk84a7r",
  //     "id": myUserId
  //   };
  //   Webservice.postRequest(
  //       uri: Global.USERS_LIST,
  //       body: body,
  //       onSuccess: (response) {
  //         ContactListModel contactListModel =
  //             contactListModelFromJson(response);
  //         if (contactListModel.success!) {
  //           usersList.value = contactListModel.list!;
  //           duplicateUsersList.value = usersList.value;
  //         }
  //       });
  // }

  Widget contactItem(UsersList users) {
    if (users.userId == myUserId) {
      print(users);
    }
    return InkWell(
      onTap: () {
        if (widget.forMakeGroup) {
          users.isSelected.value = !users.isSelected.value;
        } else {
          var selUser = [
            {
              "groups": myGroups.value,
              "mobile_email": myMobileEmail.value,
              "name": myUserName.value,
              "userId": myUserId,
              "profilePicture": myProfilePicture.value
            },
            {
              "groups": users.groups,
              "mobile_email": users.mobileEmail,
              "name": users.name,
              "userId": users.userId,
              "profilePicture": users.profilePicture
            }
          ];
          var param = {
            'secretKey': secKey,
            'isGroup': false,
            'createdBy': myUserId,
            'groupId': '',
            'groupImage': '',
            'members': [users.userId, myUserId],
            'isDeactivateUser': false,
            'modifiedBy': "",
            'name': "",
            "online": [],
            "pinnedGroup": [],
            "readCount": [
              {"unreadCount": "0", "userId": ""}
            ],
            "typing": [],
            "blockUsers": [],
            "viewBy": [myUserId, users.userId],
            "recentMessage": {},
            'users': selUser,
          };
          chat(param);
          // chat(users.userId, users: [
          //
          // ]);
          // getUsers([users.id, myUserId]);
          // getUserDetail([users.id, myUserId], selectedId: users.id);
        }
      },
      child: Row(
        children: [
          widget.forMakeGroup
              ? Obx(() => users.isSelected.value
                  ? const Icon(Icons.check_box)
                  : const Icon(Icons.check_box_outline_blank))
              : const SizedBox.shrink(),
          Padding(
            padding:
                EdgeInsets.only(left: widget.forMakeGroup ? 10 : 0, right: 10),
            child: Common.profileNetworkImage(
              borderRadius: 48.0,
              height: 48.0,
              width: 48.0,
              imageUrl: users.profilePicture,
            ),
          ),
          Text(
            "${users.name}",
            style: CustomTextStyles.medium(
                fontSize: 18.0, fontColor: Colors.black),
          )
        ],
      ),
    );
  }
}

==> agschat-0.0.15.tar.gz: example/lib/view/contact_list_view.dart <==
import 'package:agschat_example/constants.dart';
import 'package:agschat_example/core/services/stream_socket.dart';
import 'package:agschat_example/core/viewmodel/contact_list_model.dart';
import 'package:agschat_example/helper/colors.dart';
import 'package:agschat_example/helper/custom_styles.dart';
import 'package:agschat_example/view/create_group_view.dart';
import 'package:agschat_example/view/widgets/comman.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';

class ContactListView extends StatefulWidget {
  ContactListView({
    Key? key,
    this.forMakeGroup = false,
    this.forAddMember = false,
    this.participentList,
    this.groupId,
  }) : super(key: key);
  bool forMakeGroup = false;
  bool forAddMember = false;
  var participentList;
  var groupId;
  @override
  _ContactListViewState createState() => _ContactListViewState();
}

class _ContactListViewState extends State<ContactListView> {
  RxList<UsersList> usersList = <UsersList>[].obs;
  String searchText = '';
  @override
  void initState() {
    super.initState();

    getUsers();
  }

  TextEditingController searchController = TextEditingController();
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        backgroundColor: themeColor,
        elevation: 0.8,
        title: Text(
          widget.forAddMember
              ? "Add Member"
              : widget.forMakeGroup
                  ? "Create Group"
                  : "Contact list",
          style:
              CustomTextStyles.medium(fontSize: 16.0, fontColor: Colors.black),
        ),
        iconTheme: const IconThemeData(color: Colors.black),
      ),
      bottomNavigationBar: widget.forMakeGroup
          ? SafeArea(
              child: GestureDetector(
                onTap: () {
                  var selectedUserObj = [];
                  var selectedUserIds = [];
                  selectedUserObj = [];
                  selectedUserIds = [];
                  usersList.forEach((element) {
                    if (element.isSelected.value) {
                      selectedUserObj.add({
                        "groups": element.groups,
                        "mobile_email": element.mobileEmail,
                        "name": element.name,
                        "userId": element.userId,
                        "profilePicture": element.profilePicture
                      });
                      selectedUserIds.add(element.userId);
                    }
                  });

                  if (selectedUserIds.isEmpty) {
                    Common.getSnackToast(
                      title: 'Error',
                      message: "Please select user",
                    );
                  } else {
                    if (widget.forAddMember) {
                      var selectedUser = [];
                      var selectedMembers = [];
                      if (widget.participentList != null) {
                        var participents = widget.participentList;
                        participents.forEach((val) {
                          selectedUser.add(val);
                          selectedMembers.add(val['userId']);
                        });
                      }
                      usersList.forEach((element) {
                        if (element.isSelected.value) {
                          selectedUser.add(element);
                          selectedMembers.add(element.userId);
                        }
                      });

                      var parameters = {
                        "secretKey": secKey,
                        "groupId": widget.groupId,
                        "users": selectedUser,
                        "members": selectedMembers,
                        "viewBy": selectedMembers
                      };
                      addMember(parameters, context: context);
                    } else {
                      Navigator.push(
                        context,
                        MaterialPageRoute(
                          builder: (context) => CreateGroup(
                            selectedUserObj: selectedUserObj,
                            selectedUserIds: selectedUserIds,
                          ),
                        ),
                      );
                    }
                  }
                },
                child: Container(
                  height: 50,
                  margin: const EdgeInsets.only(top: 16, left: 20, right: 20),
                  decoration: BoxDecoration(
                    borderRadius: BorderRadius.circular(8.0),
                    color: Colors.blue,
                  ),
                  child: Center(
                    child: Text(
                      widget.forAddMember ? "Add" : "Next",
                      style: CustomTextStyles.semiBold(
                          fontSize: 18.0, fontColor: Colors.white),
                    ),
                  ),
                ),
              ),
            )
          : const SizedBox(),
      body: Column(
        children: [
          Padding(
            padding:
                const EdgeInsets.only(left: 20, right: 20, top: 8, bottom: 8),
            child: TextField(
              controller: searchController,
              onChanged: (val) {
                setState(() {
                  searchText = val;
                });
              },
              decoration: InputDecoration(
                hintText: "Search chat",
                hintStyle: CustomTextStyles.medium(
                    fontSize: 14.0, fontColor: Colors.black38),
                filled: true,
                fillColor: const Color(0xffEEEEEF),
                border: searchCommonBorderStyle,
                enabledBorder: searchCommonBorderStyle,
                disabledBorder: searchCommonBorderStyle,
                focusedBorder: searchCommonBorderStyle,
                focusedErrorBorder: searchCommonBorderStyle,
                errorBorder: searchCommonBorderStyle,
                contentPadding: const EdgeInsets.only(left: 6, right: 6),
                prefixIcon: const Padding(
                    padding: EdgeInsetsDirectional.only(start: 6.0),
                    child: Icon(Icons.search)),
              ),
            ),
          ),
          Expanded(
              child: StreamBuilder(
                  stream: getUsersSocket.getResponse,
                  builder:
                      (BuildContext context, AsyncSnapshot<dynamic> snapshot) {
                    if (snapshot.connectionState == ConnectionState.waiting) {
                      return const Center(child: CircularProgressIndicator());
                    }
                    usersList.clear();

                    snapshot.data['list'].forEach((val) {
                      usersList.add(UsersList(
                        userId: val['userId'],
                        profilePicture: val['profilePicture'],
                        groups: val['groups'],
                        mobileEmail: val['mobile_email'],
                        name: val['name'],
                        serverUserId: val['serverUserId'],
                      ));
                    });
                    if (widget.forAddMember) {
                      if (widget.participentList != null) {
                        if (usersList.isNotEmpty) {
                          var participentList = widget.participentList;
                          participentList.forEach((val) {
                            usersList.removeWhere(
                                (element) => element.userId == val['userId']);
                            usersList.refresh();
                          });
                        }
                      }
                    }
                    if (searchText.isNotEmpty) {
                      usersList.value = usersList.value.where((element) {
                        return element.name
                            .toString()
                            .toLowerCase()
                            .contains(searchText.toLowerCase());
                      }).toList();
                    }
                    return usersList.isEmpty
                        ? const Center(
                            child: Text("Data not found"),
                          )
                        : Obx(
                            () => ListView.separated(
                              padding: const EdgeInsets.only(
                                  left: 20, right: 20, top: 8),
                              itemBuilder: (context, index) {
                                return contactItem(usersList[index]);
                              },
                              separatorBuilder: (_, index) {
                                return const SizedBox(
                                  height: 8,
                                );
                              },
                              itemCount: usersList.length,
                            ),
                          );
                  }))
        ],
      ),
    );
  }

  var searchCommonBorderStyle = const OutlineInputBorder(
    borderSide: BorderSide(
      color: Color(0xffE6E6E6),
    ),
  );

  // void getContactList() {
  //   var body = {
  //     "secretKey":
  //         "U2FsdGVkX18AsTXTniJJwZ9KaiRWQki0Gike3TN%2BQyXws0hyLIdcRN4abTk84a7r",
  //     "id": myUserId
  //   };
  //   Webservice.postRequest(
  //       uri: Global.USERS_LIST,
  //       body: body,
  //       onSuccess: (response) {
  //         ContactListModel contactListModel =
  //             contactListModelFromJson(response);
  //         if (contactListModel.success!) {
  //           usersList.value = contactListModel.list!;
  //           duplicateUsersList.value = usersList.value;
  //         }
  //       });
  // }

  Widget contactItem(UsersList users) {
    if (users.userId == myUserId) {
      print(users);
    }
    return InkWell(
      onTap: () {
        if (widget.forMakeGroup) {
          users.isSelected.value = !users.isSelected.value;
        } else {
          var selUser = [
            {
              "groups": myGroups.value,
              "mobile_email": myMobileEmail.value,
              "name": myUserName.value,
              "userId": myUserId,
              "profilePicture": myProfilePicture.value
            },
            {
              "groups": users.groups,
              "mobile_email": users.mobileEmail,
              "name": users.name,
              "userId": users.userId,
              "profilePicture": users.profilePicture
            }
          ];
          var param = {
            'secretKey': secKey,
            'isGroup': false,
            'createdBy': myUserId,
            'groupId': '',
            'groupImage': '',
            'members': [users.userId, myUserId],
            'isDeactivateUser': false,
            'modifiedBy': "",
            'name': "",
            "online": [],
            "pinnedGroup": [],
            "readCount": [
              {"unreadCount": "0", "userId": ""}
            ],
            "typing": [],
            "blockUsers": [],
            "viewBy": [myUserId, users.userId],
            "recentMessage": {},
            'users': selUser,
          };
          chat(param, context: context);
          // chat(users.userId, users: [
          //
          // ]);
          // getUsers([users.id, myUserId]);
          // getUserDetail([users.id, myUserId], selectedId: users.id);
        }
      },
      child: Row(
        children: [
          widget.forMakeGroup
              ? Obx(() => users.isSelected.value
                  ? const Icon(Icons.check_box)
                  : const Icon(Icons.check_box_outline_blank))
              : const SizedBox.shrink(),
          Padding(
            padding:
                EdgeInsets.only(left: widget.forMakeGroup ? 10 : 0, right: 10),
            child: Common.profileNetworkImage(
              borderRadius: 48.0,
              height: 48.0,
              width: 48.0,
              imageUrl: users.profilePicture,
            ),
          ),
          Text(
            "${users.name}",
            style: CustomTextStyles.medium(
                fontSize: 18.0, fontColor: Colors.black),
          )
        ],
      ),
    );
  }
}
